<template>
    <v-row row justify-center>
        <!-- category Add -->
        <CategoryAdd ref="categoryAdd"></CategoryAdd>
        <v-dialog v-model="dialog" width="950">
            <v-card>
                <v-card-title>
                    <v-icon medium>remove_circle_outline</v-icon>
                    <span class="headline">
                        {{ trans('messages.add_expense') }}
                    </span>
                    <v-spacer></v-spacer>
                    <v-btn text @click="dialog = false" icon>
                        <v-icon>clear</v-icon>
                    </v-btn>
                </v-card-title>
                <v-divider></v-divider>
                <v-card-text>
                    <v-container >
                        <v-row >
                            <v-col xs="12" md="3">
                                <v-autocomplete
                                    item-text="name"
                                    item-value="id"
                                    :items="categories"
                                    v-model="category_id"
                                    :label="trans('messages.category')"
                                    v-validate="'required'"
                                    data-vv-name="category"
                                    :data-vv-as="trans('messages.category')"
                                    :error-messages="errors.collect('category')"
                                    required
                                ></v-autocomplete>
                            </v-col>
                            <v-col md="1">
                                <v-btn @click="createCategory" small color="primary" fab dark>
                                    <v-icon>add</v-icon>
                                </v-btn>
                            </v-col>
                            <v-col xs6 md="4">
                                <v-text-field
                                    v-model="expense.ref_no"
                                    :label="trans('messages.ref_no')"
                                >
                                </v-text-field>
                            </v-col>
                            <v-col xs="12" md="4">
                                <div class="v-input v-text-field theme--light">
                                    <div class="v-input__control">
                                        <div class="v-input__slot">
                                            <div class="v-text-field__slot">
                                                <label
                                                    aria-hidden="true"
                                                    class="v-label v-label--active theme--light flat_picker_label"
                                                >
                                                    {{ trans('messages.date') }}
                                                </label>
                                                <flat-pickr
                                                    v-model="transaction_date"
                                                    v-validate="'required'"
                                                    name="date"
                                                    required
                                                    :config="flatPickerDate()"
                                                    :data-vv-as="trans('messages.date')"
                                                ></flat-pickr>
                                            </div>
                                        </div>
                                        <div class="v-messages theme--light error--text">
                                            {{ errors.first('date') }}
                                        </div>
                                    </div>
                                </div>
                            </v-col>
                            <v-col xs="12" md="3">
                                <div class="v-input v-text-field theme--light">
                                    <div class="v-input__control">
                                        <div class="v-input__slot">
                                            <div class="v-text-field__slot">
                                                <label
                                                    aria-hidden="true"
                                                    class="v-label v-label--active theme--light flat_picker_label"
                                                >
                                                    {{ trans('messages.due_date') }}
                                                </label>
                                                <flat-pickr
                                                    v-model="due_date"
                                                    name="due_date"
                                                    :config="flatPickerDate()"
                                                ></flat-pickr>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </v-col>
                            <v-col xs="12" md="3">
                                <v-text-field
                                    type="number"
                                    v-model="expense.total"
                                    :label="trans('messages.total')"
                                    v-validate="'required'"
                                    data-vv-name="total"
                                    :data-vv-as="trans('messages.total')"
                                    :error-messages="errors.collect('total')"
                                    required
                                ></v-text-field>
                            </v-col>
                            <v-col xs="12" md="3">
                                <v-autocomplete
                                    item-text="name"
                                    item-value="id"
                                    :items="employees"
                                    v-model="expense.expense_for"
                                    :label="trans('messages.expense_for')"
                                ></v-autocomplete>
                            </v-col>
                            <v-col xs="12" md="3">
                                <v-autocomplete
                                    item-text="name"
                                    item-value="id"
                                    :items="projects"
                                    v-model="expense.project_id"
                                    :label="trans('messages.project')"
                                ></v-autocomplete>
                            </v-col>
                            <v-col xs="12" sm="12" md="12">
                                <v-textarea
                                    rows="3"
                                    v-model="expense.notes"
                                    :label="trans('messages.notes')"
                                ></v-textarea>
                            </v-col>
                        </v-row>
                    </v-container>
                </v-card-text>
                <v-divider></v-divider>
                <v-card-actions>
                    <v-spacer></v-spacer>
                    <v-btn color="green darken-1" text @click="dialog = false">
                        {{ trans('messages.close') }}
                    </v-btn>
                    <v-btn color="success" @click="store" :loading="loading" :disabled="loading">
                        {{ trans('messages.save') }}
                    </v-btn>
                </v-card-actions>
            </v-card>
        </v-dialog>
    </v-row>
</template>
<script>
import CategoryAdd from '../../common/projects/category/Add';
export default {
    components: {
        CategoryAdd,
    },
    data() {
        return {
            dialog: false,
            categories: [],
            employees: [],
            projects: [],
            category_id: null,
            expense: [],
            transaction_date: '',
            due_date: '',
            loading: false,
        };
    },
    mounted() {
        const self = this;
        self.$eventBus.$on('updateCategoryList', data => {
            self.categories.push(data);
            self.category_id = data.id;
        });
    },
    beforeDestroy() {
        const self = this;
        self.$eventBus.$off('updateCategoryList');
    },
    methods: {
        create() {
            const self = this;
            self.$validator.reset();
            self.employees = [];
            self.categories = [];
            self.projects = [];
            self.expense = [];
            (self.category_id = null),
                (self.transaction_date = ''),
                (self.due_date = ''),
                axios
                    .get('/expenses/create')
                    .then(function(response) {
                        self.employees = response.data.employees;
                        self.categories = response.data.categories;
                        self.projects = response.data.projects;
                        self.dialog = true;
                    })
                    .catch(function(error) {
                        console.log(error);
                    });
        },
        createCategory() {
            const self = this;
            var data = { type: 'expenses' };
            self.$refs.categoryAdd.create(data);
        },
        store() {
            const self = this;
            let data = _.pick(self.expense, [
                'ref_no',
                'total',
                'expense_for',
                'project_id',
                'notes',
            ]);
            data.category_id = self.category_id;
            data.transaction_date = self.transaction_date;
            data.due_date = self.due_date;

            self.$validator.validateAll().then(result => {
                if (result == true) {
                    self.loading = true;
                    axios
                        .post('/expenses', data)
                        .then(function(response) {
                            self.loading = false;
                            self.$store.commit('showSnackbar', {
                                message: response.data.msg,
                                color: response.data.success,
                            });

                            if (response.data.success === true) {
                                self.dialog = false;
                                self.$eventBus.$emit('updateExpenseTable');
                            }
                        })
                        .catch(function(error) {
                            console.log(error);
                        });
                }
            });
        },
    },
};
</script>
